#ifndef __DEFAULT_EMPTY_SCENE_WIDGET_H__
#define __DEFAULT_EMPTY_SCENE_WIDGET_H__


// Includes Projection Designer headers
#include <projdesigner/include/interfaces.h>

// Includes the ui_ header
#include "ui_defaultemptyscenewidget.h"

// Includes local headers
#include "DefaultEmptySceneContent.h"

/**
 * Implementation of the DefaultEmptySceneWidget class.
 *
 * This widget is used in a stacked widget with all the other sceneprojectors,
 * to configure the Empty Scene. As the empty scene as no parameter, this widget
 * is quite simple: it is empty.
 *
 */
class DefaultEmptySceneWidget : public SceneWidget,
				private Ui::DefaultEmptySceneWidget
{
    Q_OBJECT
		

public:


    /**
     * Default constructor.
     *
     */
    DefaultEmptySceneWidget(SceneInterface *plugin, QWidget* pParent=0, Qt::WFlags flag=0);


    /**
     * Destructor.
     *
     */
    ~DefaultEmptySceneWidget();


    /**
     * Updates the widget.
     *
     * This method can be used it two ways: to force a refresh or to update the
     * data of the widget.
     *
     * @param content A const pointer on the contents to be used for the widget.
     *                This contents will be duplicated in the widget. If content
     *                is NULL, the current content are used and the refresh is
     *                forced. If no content are given, NULL is used.
     *
     */
    void updateGUI(const SceneContent* data=NULL);


    /**
     * Gets the widget contents.
     *
     * @return A const reference on the content of the widget.
     *
     */
    const SceneContent& content(void) const {return m_content;}


signals:


    /**
     * [signal] Notify that the contents of the widget have changed.
     *
     * This signal will never be emited, because there is no control in the
     * widget. It is only implemented because the 
     *     void SceneWidget::dataChanged(const SceneContent&)
     * is a pure virtual signal.
     *
     * @param content A const reference on the new contents (the same as 
     *                returned by the content() method).
     *
     */
    virtual void dataChanged(const SceneContent&);


private:


    /// The current DefaultEmptySceneContent of the widget.
    DefaultEmptySceneContent m_content;


};

#endif // __DEFAULT_EMPTY_SCENE_WIDGET_H__
